var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

/* global test, jest, expect */

import React from 'react';
import renderer from 'react-test-renderer';
import { mount } from 'enzyme';
import color, { red } from '../../helpers/color';

import Twitter from './Twitter';
import { Swatch } from '../common';

test('Twitter renders correctly', function () {
  var tree = renderer.create(React.createElement(Twitter, red)).toJSON();
  expect(tree).toMatchSnapshot();
});

test('Twitter `triangle="hide"`', function () {
  var tree = renderer.create(React.createElement(Twitter, _extends({}, red, { triangle: 'hide' }))).toJSON();
  expect(tree).toMatchSnapshot();
});

test('Twitter `triangle="top-right"`', function () {
  var tree = renderer.create(React.createElement(Twitter, _extends({}, red, { triangle: 'top-right' }))).toJSON();
  expect(tree).toMatchSnapshot();
});

test('Twitter onChange events correctly', function () {
  var changeSpy = jest.fn(function (data) {
    expect(color.simpleCheckForValidColor(data)).toBeTruthy();
  });
  var tree = mount(React.createElement(Twitter, _extends({}, red, { onChange: changeSpy })));
  expect(changeSpy).toHaveBeenCalledTimes(0);
  var swatches = tree.find(Swatch);
  swatches.at(0).childAt(0).simulate('click');

  expect(changeSpy).toHaveBeenCalled();
});

test('Twitter with onSwatchHover events correctly', function () {
  var hoverSpy = jest.fn(function (data) {
    expect(color.simpleCheckForValidColor(data)).toBeTruthy();
  });
  var tree = mount(React.createElement(Twitter, _extends({}, red, { onSwatchHover: hoverSpy })));
  expect(hoverSpy).toHaveBeenCalledTimes(0);
  var swatches = tree.find(Swatch);
  swatches.at(0).childAt(0).simulate('mouseOver');

  expect(hoverSpy).toHaveBeenCalled();
});